<?php

namespace App\Http\Controllers\API\v1;

use App\Http\Controllers\Controller;
use App\Models\Menu;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Throwable;

class MenuController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        DB::enableQueryLog();
            $perPage = $request->input('per_page',PHP_INT_MAX);
            $keyword = $request->input('keyword', '');
            $data = Menu::where(function ($query) use ($keyword) {
                // $keyword = str_replace(" ","%",$keyword);
                $query->where('name', 'like', '%'.$keyword.'%')
                    ->orWhere('description', 'like', '%'.$keyword.'%');
            })
            ->orderBy('name');
            $data= $data->get();
            
            $data = $data->paginate($perPage);
            return response()->json($data);
    }

     public function list(Request $request)
    {
        $data = Menu::orderByDesc('sort')->get();

        return response()->json(["data" => $data]);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validator = Validator::make($request->all(), [
            'name' => 'required|min:2|unique:menus,name'
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], Response::HTTP_UNPROCESSABLE_ENTITY);
        }

        DB::connection()->beginTransaction();

        try {
            $data = Menu::create($request->all());

            DB::connection()->commit();

            return response()->json($data);

        } catch (Throwable $e) {
            DB::connection()->rollback();
            return response()->json([
                'status'  => false,
                'message' => 'Unable to process request. Please try again.',
                'data'    => $e->getMessage()
            ]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(int $id)
    {
        $data = Menu::find($id);
        if (!$data) {
            return response()->json(['messages' => 'No data found.'], 202);
        }
        return response()->json($data);
    }

    public function all(Request $request)
    {
        DB::enableQueryLog();
        $data = Menu::select('menus.*', 'parent.name as parent_name')
                    ->orderBy('menus.parent_id')->orderBy('menus.sort')
                    ->leftJoin('menus as parent', 'parent.id', '=', 'menus.parent_id');
        if ($request->keyword) {
            $keyword = "%$request->keyword%";
            $data->where(function($query) use ($keyword) {
                $query->where('menus.name', 'like', $keyword)
                    ->orWhere('parent.name', 'like', $keyword);
            });
        }

        $data = $data->get();
        $data = $data->toArray();
        // dd($data);
        $menus = [];
        $parents = array_filter($data, function ($parent) {
            return $parent['parent_id'] == 0;
        });
        foreach($parents as $row) {
            $child = array_filter($data, function ($child) use ($row) {
                return $child['parent_id'] == $row['id'];
            });
            $menus[] = [
                'parent' => $row,
                'child' => !empty($child) ? $child : null,
            ];
        }
        return response()->json([
            'status'  => true,
            'message' => 'All menus',
            'data'    => $menus
        ]);
    }
    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, int $id)
    {
        $data = Menu::find($id);

        if (!$data) {
            return response()->json(['messages' => 'No data found.'], 202);
        }

        DB::connection()->beginTransaction();

        try {

            $data->fill($request->all());
            $data->save();

            $data->touch();

            DB::connection()->commit();

            return response()->json([
                'status' => true,
                'data' => $data
            ]);

        } catch (Throwable $e) {
            DB::connection()->rollback();
            return response()->json([
                'status'  => false,
                'message' => 'Unable to process request. Please try again.',
                'data'    => $e->getMessage()
            ]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $data = Menu::find($id);

        if (!$data) {
            return response()->json(['messages' => 'No data found.'], 202);
        }

        DB::connection()->beginTransaction();

        try {
            $data->delete();

            DB::connection()->commit();

            return response()->json([
                'status'  => true,
                'message' => 'Record successfully deleted.',
                'data'    => $data,
            ]);

        } catch (Throwable $e) {
            DB::connection()->rollback();
            return response()->json([
                'status'  => false,
                'message' => 'Unable to process request. Please try again.',
                'data'    => $e->getMessage()
            ]);
        }
    }


    public function userMenu(Request $request, $user_id)
    {
        // dd($request->input('store_id'));
        $user = User::find($user_id);
        if($user->roles[0]->level == 100) {
            $data = Menu::select('menus.*', 'parent.name as parent_name')
            ->orderBy('menus.parent_id')->orderByRaw('CAST(menus.sort AS UNSIGNED) ASC')
            ->leftJoin('menus as parent', 'parent.id', '=', 'menus.parent_id')
            ->where('menus.enabled', '1');
        }
        else {
            DB::enableQueryLog();
            $roles = array_column($user->roles->toArray(), 'id');
            $data = Menu::with('parent')->select('menus.*', 'parent.name as parent_name','parent.icon AS parent_icon','parent.sort as parent_sort', 'parent.url as parent_url')
                ->distinct('menu.id')
                ->orderBy('menus.parent_id')->orderByRaw('CAST(menus.sort AS UNSIGNED) ASC')
                ->join('modules', 'menus.id', '=', 'modules.menu_id')
                ->join('role_permissions', function($join) use ($request, $roles) {
                    $join->on('modules.id', '=', 'role_permissions.module_id')
                        ->on('role_permissions.store_id', '=', DB::raw($request->input('store_id')))
                        ->whereIn('role_permissions.role_id', $roles);
                })
                ->leftJoin('menus as parent', 'parent.id', '=', 'menus.parent_id')
                ->where('menus.enabled', '1');
                // dd(\DB::getQueryLog());
        }

        $data = $data->get();
        $data = $data->toArray();
        $parent_ids = array_column($data,'parent_id');
        // dd($parent_ids);
        $menus = [];
        // $parents = array_filter($data, function ($parent) {
        //     return $parent['parent_id'] == 0;
        // });
        $parents = Menu::whereIn('id', $parent_ids)->get();
        foreach($parents as $row) {
            $child = array_filter($data, function ($child) use ($row) {
                return $child['parent_id'] == $row['id'];
            });
            $menus[] = [
                'parent' => $row,
                'child' => !empty($child) ? $child : null,
            ];
        }
        // dd($menus);
        return response()->json([
            'status'  => true,
            'message' => 'All menus',
            'data'    => $menus
        ]);
    }
    // public function userMenu(Request $request, $user_id)
    // {
    //     // dd($request->input('ou_code'));
    //     // \DB::enableQueryLog();
    //     $user = User::find($user_id);
    //     if($user->roles[0]->level == 100) {
    //         $data = Menu::select('menus.*', 'parent.name as parent_name')
    //             ->orderBy('menus.parent_id')->orderByRaw('CAST(menus.sort AS UNSIGNED) ASC')
    //             ->leftJoin('menus as parent', 'parent.id', '=', 'menus.parent_id')
    //             ->where('menus.enabled', '1');
    //     }
    //     else {
    //         $data = Menu::select('menus.*', 'parent.name as parent_name','parent.icon AS parent_icon','parent.sort as parent_sort', 'parent.url as parent_url')
    //             ->orderBy('menus.parent_id')->orderByRaw('CAST(menus.sort AS UNSIGNED) ASC')
    //             ->leftJoin('menus as parent', 'parent.id', '=', 'menus.parent_id')
    //             // ->leftJoin('user_menu_access as umc', 'umc.id', '=', 'menus.id')
    //             // ->where('umc.user_id', $user_id)
    //             // ->where('umc.ou_code', $request->input('ou_code'))
    //             ->where('menus.enabled', '1');
    //     }
    //     if ($request->keyword) {
    //         $keyword = "%$request->keyword%";
    //         $data->where(function($query) use ($keyword) {
    //             $query->where('menus.name', 'like', $keyword)
    //             ->orWhere('parent.name', 'like', $keyword);
    //         });
    //     }

    //     $data = $data->get();
    //     // dd(\DB::getQueryLog());
    //     $data = $data->toArray();
    //     // dd($data);
    //     $menus = [];
    //     $parents = array_filter($data, function ($parent) {
    //         return $parent['parent_id'] == 0;
    //     });
    //     foreach($parents as $row) {
    //         $menus[] = [
    //             'parent' => $row,
    //             'child' => array_filter($data, function ($child) use ($row) {
    //                 return $child['parent_id'] == $row['id'];
    //             }),
    //         ];
    //     }
    //     return response()->json([
    //         'status'  => true,
    //         'message' => 'All menus',
    //         'data'    => $menus
    //     ]);
    // }
}
