<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use OwenIt\Auditing\Contracts\Auditable;
use OwenIt\Auditing\Auditable as AuditableTrait;

class Product extends Model implements Auditable
{
    use HasFactory, SoftDeletes, AuditableTrait;

     /**
     * The attributes that are guarded and NOT mass assignable.
     *
     * @var array<int, string>
     */
    protected $guarded = [
        'deleted_at',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
        'deleted_at' => 'datetime',
    ];

    public function variations()
    {
        return $this->hasMany(
            Variation::class,
            'product_id',
            'id',
        );
    }

    public function brand()
    {
        return $this->hasOne(
            Brand::class,
            'id',
            'brand_id'
        );
    }
    
    public function categories()
    {
        return $this->belongsToMany(
            Category::class,
            ProductCategory::class,
            'product_id',
            'category_id',
        );
    }

    public function images()
    {
        return $this->belongsToMany(
            File::class,
            ProductImage::class,
            'product_id',
            'file_id',
        )->withPivot('default');
    }
    
    public function attributes()
    {
        return $this->belongsToMany(
            Attribute::class,
            ProductAttribute::class,
            'product_id',
            'attribute_id',
        );
    }

    // protected $appends = [
    //     'stores',
    //     'quantity',
    // ];
    
    // public function getStoresAttribute() {
    //     $stores = ProductVariation::select('stores.*')
    //         ->join('store_product_variations', 'product_variations.id', '=', 'store_product_variations.product_variation_id')
    //         ->join('stores', 'store_product_variations.store_id', '=', 'stores.id')
    //         ->where('product_variations.product_id','=', $this->attributes['id'])
    //         ->get();
    //     return $stores;
    // }
    

    
    
}
