<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use OwenIt\Auditing\Contracts\Auditable;
use OwenIt\Auditing\Auditable as AuditableTrait;

class StockCard extends Model implements Auditable
{
    use HasFactory, SoftDeletes, AuditableTrait;

    
    /**
     * The attributes that are guarded and NOT mass assignable.
     *
     * @var array<int, string>
     */
    protected $guarded = [
        'deleted_at',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
        'deleted_at' => 'datetime',
    ];

    protected $with = [
        'store',
        'warehouse',
    ];

    public function store()
    {
        return $this->hasOne(Store::class, 'id', 'store_id');
    }
    public function warehouse()
    {
        return $this->hasOne(Warehouse::class, 'id', 'warehouse_id');
    }
    public function variation()
    {
        return $this->hasOne(Variation::class, 'id', 'variation_id');
    }
    public function product()
    {
        return $this->hasOne(Product::class, 'id', 'product_id');
    }

}
