<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use OwenIt\Auditing\Contracts\Auditable;
use OwenIt\Auditing\Auditable as AuditableTrait;

class Variation extends Model implements Auditable
{
    use HasFactory, SoftDeletes, AuditableTrait;

    protected $table = 'variations';
    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'id',
        'old_id',
        'product_id',
        'product_no',
        'sku',
        'description',
        'slug',
        'price',
        'wholesale_price',
        'max_order_qty',
        'min_order_qty',
        'reorder_qty',
        'oum',
        'length',
        'width',
        'height',
        'weight',
        'specs',
        'published_at',
        'enabled',
        'created_at',
        'updated_at',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
        'deleted_at' => 'datetime',
    ];

    protected $appends = [
        'current_price',
        'inventory_data',
    ];
    public function images()
    {
        return $this->belongsToMany(
            File::class,
            VariationImage::class,
            'variation_id',
            'file_id',
        );
    }

    public function attributes()
    {
        return $this->belongsToMany(
            Attribute::class,
            VariationAttributeValue::class,
            'variation_id',
            'attribute_id',
        )->withPivot('value');
    }

    public function store_details()
    {
        return $this->belongsToMany(
            Store::class,
            StoreProductDetails::class,
            'variation_id',
            'store_id',
        )->withPivot([
            'product_id', 
            'max_order_qty', 
            'min_order_qty', 
            'max_qty', 
            'reorder_qty',
            'enabled',
            'default',
        ]);
    }
    public function inventories()
    {
        return $this->hasMany(
            Inventory::class,
            'variation_id',
            'id'
        );
            
    }
    public function stock_cards()
    {
        return $this->hasMany(
            StockCard::class,
            'variation_id',
            'id'
        );
            
    }
    public function getCurrentPriceAttribute() {
        $today = date('Y-m-d H:i:s');
        $price = null;
        $record = ProductPrice::select('price')
            ->where('effectivity_date', '<=', $today)
            ->orderByDesc('effectivity_date')
            ->first();
        if($record) {
            $price = $record->price;
        }
        return $price;
    }
    public function getInventoryDataAttribute() {
        $record = Inventory::where('variation_id', '=', $this->attributes['id'])->get();
        return $record;
    }
}
