<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\API\AuthController;
use App\Http\Controllers\API\v1\UserController;
use App\Http\Controllers\API\v1\RoleController;
use App\Http\Controllers\API\v1\PermissionController;
use App\Http\Controllers\API\v1\ModuleController;
use App\Http\Controllers\API\v1\MenuController;
use App\Http\Controllers\API\v1\StoreController;
use App\Http\Controllers\API\v1\CategoryController;
use App\Http\Controllers\API\v1\BrandController;
use App\Http\Controllers\API\v1\AttributeController;
use App\Http\Controllers\API\v1\UnitOfMeasureController;
use App\Http\Controllers\API\v1\WarehouseController;
use App\Http\Controllers\API\v1\FloorController;
use App\Http\Controllers\API\v1\RackController;
use App\Http\Controllers\API\v1\BinController;
use App\Http\Controllers\API\v1\InventoryLocationController;
use App\Http\Controllers\API\v1\SupplierController;
use App\Http\Controllers\API\v1\ProductController;
use App\Http\Controllers\API\v1\VariationController;
use App\Http\Controllers\API\v1\FileController;
use App\Models\InventoryLocation;
use App\Models\UnitOfMeasure;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/

// Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
//     return $request->user();
// });

Route::controller(AuthController::class)->group(function () {
    Route::post('login', 'login');
    Route::post('logout', 'logout');
    Route::post('refresh', 'refresh');
    Route::post('register', 'register');
});

Route::group(['prefix' => 'v1', 'middleware' => 'auth:api'], function () {
    Route::group(['prefix' => 'settings'], function () {

        // Route::get('/menu/parent', [MenuController::class, 'getParent']);
        Route::get('/all-menus', [MenuController::class, 'all']);
        Route::get('/user-menus/{user_id}', [MenuController::class, 'userMenu']);

        Route::get('/role-store-access/{id}', [RoleController::class, 'RoleStoreAccess']);
        Route::get('/all-role-store-access', [RoleController::class, 'AllRoleStoreAccess']);
        Route::post('/role-permissions', [PermissionController::class, 'SaveRolePermissions']);
        Route::get('/role-permissions', [PermissionController::class, 'getAllRolePermissions']);
        Route::get('/role-permissions/{id}', [PermissionController::class, 'getRolePermissions']);
        Route::put('/save-role-permissions', [PermissionController::class, 'SaveRolePermissions']);
        Route::get('/store-permissions', [PermissionController::class, 'StorePermissions']);


        Route::get('/user-role/{id}', [UserController::class, 'UserRole']);

        Route::post('/user-set-default-ou/{id}', [UserController::class, 'setDefaultOU']);

        Route::post('/menus/user', [MenuController::class, 'saveMenuUser']);
        Route::get('/menu-list', [MenuController::class, 'list']);

        Route::apiResources([
            'users' => UserController::class,
            'roles' => RoleController::class,
            'permissions' => PermissionController::class,
            'modules' => ModuleController::class,
            'menus' => MenuController::class,
        ]);
    });
    Route::get('/files', [FileController::class, 'show']);
    
    Route::get('/all-products', [ProductController::class, 'all']);
    Route::post('/import-products', [ProductController::class, 'import']);

    Route::apiResources([
        'stores' => StoreController::class,
        'categories' => CategoryController::class,
        'brands' => BrandController::class,
        'attributes' => AttributeController::class,
        'unit-of-measures' => UnitOfMeasureController::class,
        'warehouses' => WarehouseController::class,
        'floors' => FloorController::class,
        'racks' => RackController::class,
        'bins' => BinController::class,
        'inventory-locations' => InventoryLocationController::class,
        'suppliers' => SupplierController::class,
        'products' => ProductController::class,
        'variations' => VariationController::class,
    ]);
});
